@@ -27,6 +27,8 @@ api_keys = dict(
     files = os.getenv('COGNITE_API_KEY_FILES')
 )
 
+SERVICE_NAME = os.getenv("SERVICE_NAME")
+
 def set_up_cdf_client(context='run'):
     """
     Set up the global client used by most helpers. This needs to be called before using any helper. Should be called once with all required keys.
@@ -95,6 +97,7 @@ def create_function(
         logging.debug(f"Deleted function {function_name}")
     except CogniteNotFoundError:
         pass
+    env_vars = dict(SERVICE_NAME=SERVICE_NAME)
     function = client.functions.create( 
         name=function_name, 
         folder=folder, 
@@ -102,9 +105,12 @@ def create_function(
         external_id=function_name,
         description=description,
         owner=owner,
-        secrets=secrets
+        secrets=secrets,
+        env_vars=env_vars
+    )
+    logging.debug(
+        f"Created {function_name}: {folder=}, {handler_path=}, {env_vars=}"
     )
-    logging.debug(f"Created {function_name}: {folder=}, {handler_path=}")
 
     return function
 
