@@ -58,7 +58,7 @@ def deploy(model_settings):
             logging.debug("model code => deployment folder")
             to_deployment_folder(model_code_folder)
             logging.debug("handler => deployment folder")
-            to_deployment_folder((f"akerbp.mlops.{SERVICE_NAME}","handler.py"))
+            to_deployment_folder((f"akerbp.mlops.cdf","handler.py"))
             logging.debug("project config => deployment folder")
             to_deployment_folder('mlops_settings.py')
             logging.debug("artifact folder => deployment folder")
